@@ -4,5 +4,5 @@ from .views import reactivate_user
 app_name = "useraudit"
 
 urlpatterns = [
-    url(r'/reactivate/(?P<user_id>\d+)[/]?$', reactivate_user, name="reactivate_user"),
+    url(r'reactivate/(?P<user_id>\d+)[/]?$', reactivate_user, name="reactivate_user"),
 ]
